@@ -34,7 +34,7 @@ export DEVSTACK_LOCAL_CONFIG+=$'\n'"disable_service ceilometer-api"
 export DEVSTACK_LOCAL_CONFIG+=$'\n'"disable_service ceilometer-collector"
 
 if [ "$coe" = "mesos" ]; then
-    echo "MAGNUM_GUEST_IMAGE_URL=https://fedorapeople.org/groups/magnum/ubuntu-mesos-latest.qcow2" >> $BASE/new/devstack/localrc
+    echo "MAGNUM_GUEST_IMAGE_URL=https://tarballs.openstack.org/magnum/images/ubuntu-mesos.qcow2" >> $BASE/new/devstack/localrc
 elif [ "$coe" = "k8s-coreos" ]; then
     echo "MAGNUM_GUEST_IMAGE_URL=http://beta.release.core-os.net/amd64-usr/current/coreos_production_openstack_image.img.bz2" >> $BASE/new/devstack/localrc
 elif [ "${coe}${special}" = "k8s-ironic" ]; then
