@@ -100,6 +100,29 @@ class TestQuota(api_base.FunctionalTest):
         self.assertEqual(1, len(response['quotas']))
         self.assertEqual('proj-id-1', response['quotas'][0]['project_id'])
 
+    @mock.patch("magnum.common.policy.enforce")
+    @mock.patch("magnum.common.context.make_context")
+    def test_get_all_with_pagination_limit(self, mock_context,
+                                           mock_policy):
+        mock_context.return_value = self.context
+        quota_list = []
+        for i in range(4):
+            quota = obj_utils.create_test_quota(self.context,
+                                                project_id="proj-id-"+str(i))
+            quota_list.append(quota)
+
+        self.context.is_admin = True
+        response = self.get_json('/quotas?limit=2&all_tenants=True')
+        self.assertEqual(2, len(response['quotas']))
+        expected = [r.project_id for r in quota_list[:2]]
+        res_proj_ids = [r['project_id'] for r in response['quotas']]
+        self.assertEqual(sorted(expected), sorted(res_proj_ids))
+        self.assertTrue('http://localhost/v1/quotas?' in response['next'])
+        self.assertTrue('sort_key=id' in response['next'])
+        self.assertTrue('sort_dir=asc' in response['next'])
+        self.assertTrue('limit=2' in response['next'])
+        self.assertTrue('marker=%s' % quota_list[1].id in response['next'])
+
     @mock.patch("magnum.common.policy.enforce")
     @mock.patch("magnum.common.context.make_context")
     def test_get_all_admin_all_with_pagination_marker(self, mock_context,
