@@ -50,7 +50,8 @@ class TestClusterConductorWithK8s(base.TestCase):
                        'flannel_network_subnetlen': '26',
                        'flannel_backend': 'vxlan',
                        'system_pods_initial_delay': '15',
-                       'system_pods_timeout': '1'},
+                       'system_pods_timeout': '1',
+                       'admission_control_list': 'fake_list'},
             'tls_disabled': False,
             'server_type': 'vm',
             'registry_enabled': False,
@@ -147,7 +148,8 @@ class TestClusterConductorWithK8s(base.TestCase):
                        'flannel_network_subnetlen': '26',
                        'flannel_backend': 'vxlan',
                        'system_pods_initial_delay': '15',
-                       'system_pods_timeout': '1'},
+                       'system_pods_timeout': '1',
+                       'admission_control_list': 'fake_list'},
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'no_proxy': 'no_proxy',
@@ -177,6 +179,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'flannel_backend': 'vxlan',
             'system_pods_initial_delay': '15',
             'system_pods_timeout': '1',
+            'admission_control_list': 'fake_list',
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'no_proxy': 'no_proxy',
@@ -253,6 +256,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'flannel_network_subnetlen': '26',
             'system_pods_initial_delay': '15',
             'system_pods_timeout': '1',
+            'admission_control_list': 'fake_list',
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'magnum_url': 'http://127.0.0.1:9511/v1',
@@ -335,6 +339,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'flannel_network_subnetlen': '26',
             'system_pods_initial_delay': '15',
             'system_pods_timeout': '1',
+            'admission_control_list': 'fake_list',
             'insecure_registry_url': '10.0.0.1:5000',
             'kube_version': 'fake-version',
             'magnum_url': 'http://127.0.0.1:9511/v1',
@@ -409,6 +414,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'flannel_backend': 'vxlan',
             'system_pods_initial_delay': '15',
             'system_pods_timeout': '1',
+            'admission_control_list': 'fake_list',
             'tls_disabled': False,
             'registry_enabled': False,
             'trustee_domain_id': self.mock_keystone.trustee_domain_id,
@@ -475,6 +481,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'flannel_backend': 'vxlan',
             'system_pods_initial_delay': '15',
             'system_pods_timeout': '1',
+            'admission_control_list': 'fake_list',
             'tls_disabled': False,
             'registry_enabled': False,
             'trustee_domain_id': self.mock_keystone.trustee_domain_id,
@@ -667,6 +674,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'flannel_backend': 'vxlan',
             'system_pods_initial_delay': '15',
             'system_pods_timeout': '1',
+            'admission_control_list': 'fake_list',
             'tenant_name': 'fake_tenant',
             'username': 'fake_user',
             'cluster_uuid': self.cluster_dict['uuid'],
